@@ -26,22 +26,9 @@ class OrderUtilTestCase(TestCase):
         self.order.order_subtotal = Decimal('10')
         self.order.order_total = Decimal('10')
         self.order.shipping_cost = Decimal('0')
-        
-        self.order.shipping_name = 'toto'
-        self.order.shipping_address = 'address'
-        self.order.shipping_address2 = 'address2'
-        self.order.shipping_city = 'city'
-        self.order.shipping_zip_code = 'zip'
-        self.order.shipping_state = 'state'
-        self.order.shipping_country = 'country'
-        
-        self.order.billing_name = 'toto'
-        self.order.billing_address = 'address'
-        self.order.billing_address2 = 'address2'
-        self.order.billing_city = 'city'
-        self.order.billing_zip_code = 'zip'
-        self.order.billing_state = 'state'
-        self.order.billing_country = 'country'
+
+        self.order.shipping_address_text = 'shipping address example'
+        self.order.billing_address_text = 'billing address example'
         
         self.order.save()
         
@@ -95,6 +82,17 @@ class OrderUtilTestCase(TestCase):
         order2 = Order.objects.create(user=self.user)
         ret = get_order_from_request(self.request)
         self.assertEqual(ret, order2)
+
+    def test_addresses_are_conserved_properly(self):
+        session = {}
+        session['order_id'] = self.order.id
+        setattr(self.request, 'session', session)
+        ret = get_order_from_request(self.request)
+        self.assertEqual(ret, self.order)
+        self.assertEqual(ret.shipping_address_text,
+                        self.order.shipping_address_text)
+        self.assertEqual(ret.billing_address_text,
+                        self.order.billing_address_text)
         
 
 class OrderTestCase(TestCase):
@@ -105,19 +103,8 @@ class OrderTestCase(TestCase):
         self.order.order_total = Decimal('10')
         self.order.shipping_cost = Decimal('0')
         
-        self.order.shipping_name = 'toto'
-        self.order.shipping_address = 'address'
-        self.order.shipping_address2 = 'address2'
-        self.order.shipping_zip_code = 'zip'
-        self.order.shipping_state = 'state'
-        self.order.shipping_country = 'country'
-        
-        self.order.billing_name = 'toto'
-        self.order.billing_address = 'address'
-        self.order.billing_address2 = 'address2'
-        self.order.billing_zip_code = 'zip'
-        self.order.billing_state = 'state'
-        self.order.billing_country = 'country'
+        self.order.shipping_address_text = 'shipping address example'
+        self.order.billing_address_text = 'billing address example'
         
         self.order.save()
     
@@ -288,19 +275,8 @@ class OrderPaymentTestCase(TestCase):
         self.order.order_total = Decimal('10')
         self.order.shipping_cost = Decimal('0')
         
-        self.order.shipping_name = 'toto'
-        self.order.shipping_address = 'address'
-        self.order.shipping_address2 = 'address2'
-        self.order.shipping_zip_code = 'zip'
-        self.order.shipping_state = 'state'
-        self.order.shipping_country = 'country'
-        
-        self.order.billing_name = 'toto'
-        self.order.billing_address = 'address'
-        self.order.billing_address2 = 'address2'
-        self.order.billing_zip_code = 'zip'
-        self.order.billing_state = 'state'
-        self.order.billing_country = 'country'
+        self.order.shipping_address_text = 'shipping address example'
+        self.order.billing_address_text = 'billing address example'
         
         self.order.save()
     
