@@ -1,4 +1,5 @@
 #-*- coding: utf-8 -*-
+from django.conf import settings
 from django.core import exceptions
 from django.utils.importlib import import_module
 
@@ -35,3 +36,17 @@ def load_class(class_path, setting_name=None):
             txt = 'Backend module "%s" does not define a "%s" class.' % (class_module, class_name)
         raise exceptions.ImproperlyConfigured(txt)
     return clazz
+
+
+def get_model_string(model_name):
+    """
+    Returns the model string notation Django uses for lazily loaded ForeignKeys
+    (eg 'auth.User') to prevent circular imports.
+    This is needed to allow our crazy custom model usage.
+    """
+    class_path = getattr(settings, 'SHOP_%s_MODEL' % model_name.upper().replace('_', ''), None)
+    if not class_path:
+        return 'shop.%s' % model_name
+    else:
+        klass = load_class(class_path)
+        return '%s.%s' % (klass._meta.app_label, klass.__name__)
